6387579: Usage of package-private class as parameter of a method (javax.swing.tree.DefaultTreeSelectionModel)
authorpeterz
Tue, 01 Sep 2009 15:34:21 +0400
changeset 3747 760e072cc617
parent 3746 57fdfd5896f7
child 3748 b88af44d77a8
6387579: Usage of package-private class as parameter of a method (javax.swing.tree.DefaultTreeSelectionModel) Reviewed-by: rupashka
jdk/src/share/classes/javax/swing/tree/DefaultTreeSelectionModel.java
--- a/jdk/src/share/classes/javax/swing/tree/DefaultTreeSelectionModel.java	Tue Sep 01 16:15:12 2009 +0900
+++ b/jdk/src/share/classes/javax/swing/tree/DefaultTreeSelectionModel.java	Tue Sep 01 15:34:21 2009 +0400
@@ -1067,10 +1067,13 @@
     }
 
     /**
-      * Notifies listeners of a change in path. changePaths should contain
-      * instances of PathPlaceHolder.
-      */
-    protected void notifyPathChange(Vector<PathPlaceHolder> changedPaths,
+     * Notifies listeners of a change in path. changePaths should contain
+     * instances of PathPlaceHolder.
+     *
+     * @deprecated As of JDK version 1.7
+     */
+    @Deprecated
+    protected void notifyPathChange(Vector changedPaths,
                                     TreePath oldLeadSelection) {
         int                    cPathCount = changedPaths.size();
         boolean[]              newness = new boolean[cPathCount];
@@ -1078,7 +1081,7 @@
         PathPlaceHolder        placeholder;
 
         for(int counter = 0; counter < cPathCount; counter++) {
-            placeholder = changedPaths.elementAt(counter);
+            placeholder = (PathPlaceHolder) changedPaths.elementAt(counter);
             newness[counter] = placeholder.isNew;
             paths[counter] = placeholder.path;
         }